@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ctree.c 3057 2006-11-06 17:14:37Z roms $ */
+/* $Id: ctree.c 4032 2007-11-14 16:20:00Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -249,7 +249,7 @@ void ctree_set_basetree(void)
 	
 	// top node
 #if 1
-	str = g_strdup_printf("%s w/ %s on #%i", tifiles_model_to_string(options.calc_model),
+	str = g_strdup_printf(_("%s -> %s:#%i"), tifiles_model_to_string(options.calc_model),
 		ticables_model_to_string(options.cable_model), options.cable_port);
 
 	top_node = &clc_node;
@@ -301,7 +301,7 @@ void ctree_refresh(void)
 	GdkPixbuf *pix9 = NULL;
 	GtkTreeIter parent_node;
 	GtkTreeIter child_node;
-	TNode *vars, *apps;
+	GNode *vars, *apps;
 	int i, j;
 
 	if (remote.var_tree == NULL)
@@ -350,23 +350,23 @@ void ctree_refresh(void)
 	memcpy(&parent_node, &vars_node, sizeof(GtkTreeIter));
 
 	// load pixmaps
-	pix1 = create_pixbuf("ctree_close_dir.xpm");
+	pix1 = create_pixbuf("ctree_close_dir.png");
 	pix2 = create_pixbuf("TIicon2.ico");
-	pix3 = create_pixbuf("ctree_open_dir.xpm");
-	pix4 = create_pixbuf("attr_locked.xpm");
-	pix5 = create_pixbuf("attr_archived.xpm");
+	pix3 = create_pixbuf("ctree_open_dir.png");
+	pix4 = create_pixbuf("attr_locked.png");
+	pix5 = create_pixbuf("attr_archived.png");
 	pix6 = create_pixbuf("TIicon4.ico");
 
 	// variables tree
 	vars = remote.var_tree;
-	for (i = 0; i < (int)t_node_n_children(vars); i++) 
+	for (i = 0; i < (int)g_node_n_children(vars); i++) 
 	{
-		TNode *parent = t_node_nth_child(vars, i);
+		GNode *parent = g_node_nth_child(vars, i);
 		VarEntry *fe = (VarEntry *) (parent->data);
 
 		if ((fe != NULL) || (ticalcs_calc_features(calc_handle) & FTS_FOLDER)) 
 		{
-			char *utf8 = ticonv_varname_to_utf8(options.calc_model, fe->name);
+			char *utf8 = ticonv_varname_to_utf8(options.calc_model, fe->name, -1);
 
 			gtk_tree_store_append(tree, &parent_node, &vars_node);
 			gtk_tree_store_set(tree, &parent_node, 
@@ -376,14 +376,14 @@ void ctree_refresh(void)
 			g_free(utf8);
 		}
 
-		for (j = 0; j < (int)t_node_n_children(parent); j++) 
+		for (j = 0; j < (int)g_node_n_children(parent); j++) 
 		{
-			TNode *node = t_node_nth_child(parent, j);
+			GNode *node = g_node_nth_child(parent, j);
 			gchar **row_text = g_malloc0((CTREE_NCOLS + 1) * sizeof(gchar *));
 			VarEntry *ve = (VarEntry *) (node->data);
 			char icon_name[256];
 
-			row_text[0] = ticonv_varname_to_utf8(options.calc_model, ve->name);
+			row_text[0] = ticonv_varname_to_utf8(options.calc_model, ve->name, ve->type);
 			row_text[2] = g_strdup_printf("%s", tifiles_vartype2string(options.calc_model, ve->type));
 			tilp_var_get_size(ve, &row_text[3]);
 
@@ -423,18 +423,18 @@ void ctree_refresh(void)
 
 	// Appplications tree
 	apps = remote.app_tree;
-	for (i = 0; i < (int)t_node_n_children(apps); i++) 
+	for (i = 0; i < (int)g_node_n_children(apps); i++) 
 	{
-		TNode *parent = t_node_nth_child(apps, i);
+		GNode *parent = g_node_nth_child(apps, i);
 
-		for (j = 0; j < (int)t_node_n_children(parent); j++) 
+		for (j = 0; j < (int)g_node_n_children(parent); j++) 
 		{
-			TNode *node = t_node_nth_child(parent, j);
+			GNode *node = g_node_nth_child(parent, j);
 			gchar **row_text = g_malloc0((CTREE_NCOLS + 1) * sizeof(gchar *));
 			VarEntry *ve = (VarEntry *) (node->data);
 			char icon_name[256];
 
-			row_text[0] = ticonv_varname_to_utf8(options.calc_model, ve->name);
+			row_text[0] = ticonv_varname_to_utf8(options.calc_model, ve->name, ve->type);
 			row_text[2] = g_strdup_printf("%s", tifiles_vartype2string(options.calc_model, ve->type));
 			row_text[3] = g_strdup_printf("%u", (int) (ve->size));
 
@@ -632,7 +632,6 @@ void ctree_select_vars(gint action)
 		else
 		{
 			gtk_tree_selection_select_range(sel, start_path, end_path);
-			printf("!!!\n");
 		}
 
 		gtk_tree_path_free(start_path);
