@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ctree.h 3057 2006-11-06 17:14:37Z roms $ */
+/* $Id: ctree.h 3133 2007-02-01 17:17:22Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -35,7 +35,7 @@ enum {
 #define NODE1 _("Screen")
 #define NODE2 _("Operating System")
 #define NODE3 _("Variables")
-#define NODE4 _("Apps/Archive")
+#define NODE4 _("Applications")
 #define NODE5 _("ID-LIST")
 #define NODE6 _("Clock")
 #define NODEx _("A Folder")
