@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: screenshot.c 3057 2006-11-06 17:14:37Z roms $ */
+/* $Id: screenshot.c 3976 2007-11-05 13:08:26Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -51,7 +51,7 @@ gint display_screenshot_dbox()
 	scrn_win = glade_xml_get_widget(xml, "screenshot_dbox");
 	scrn_img = glade_xml_get_widget(xml, "pixmap7");
 
-	pixbuf = create_pixbuf("screendump.xpm");
+	pixbuf = create_pixbuf("screendump.png");
 	gtk_image_set_from_pixbuf(GTK_IMAGE(scrn_img), pixbuf);
 	g_object_unref(pixbuf);
 
@@ -179,6 +179,8 @@ static void destroy_pixbuf(guchar * pixels, gpointer data)
 	g_free(pixels);
 }
 
+extern void on_manual1_activate(GtkMenuItem * menuitem, gpointer user_data);
+
 GLADE_CB void on_scdbox_button1_clicked(GtkButton * button,
 					gpointer user_data)
 {
@@ -199,16 +201,20 @@ GLADE_CB void on_scdbox_button1_clicked(GtkButton * button,
 	w = screen.width;
 	h = screen.height;
 
-	if (options.screen_blurry)
-		bytemap = screen_blurry();
+	if(options.calc_model != CALC_NSPIRE)
+	{
+		if (options.screen_blurry)
+			bytemap = screen_bw_blurry();
+		else
+			bytemap = screen_bw_convert();
+	}
 	else
-		bytemap = screen_convert();
+		bytemap = screen_gs_convert();
 
 	pixbuf = gdk_pixbuf_new_from_data(bytemap, GDK_COLORSPACE_RGB, FALSE,
 				     8, w, h, 3 * w, destroy_pixbuf, NULL);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(scrn_img), pixbuf);
 	g_object_unref(pixbuf);
-	//g_free(bytemap);
 }
 
 GLADE_CB void on_scdbox_button2_clicked(GtkButton * button,
@@ -223,9 +229,18 @@ GLADE_CB void on_scdbox_button3_clicked(GtkButton * button,
 	gtk_widget_destroy(scrn_win);
 }
 
-extern void on_manual1_activate(GtkMenuItem * menuitem, gpointer user_data);
-
 GLADE_CB void on_scdbox_button4_clicked(GtkButton * button, gpointer user_data)
 {
 	on_manual1_activate(NULL, NULL);
-} 
+}
+
+GLADE_CB void on_scdbox_button5_clicked(GtkButton * button, gpointer user_data)
+{
+	GdkPixbuf *pixbuf;
+	GtkClipboard *clipboard;
+
+	pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(scrn_img));
+
+	clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+	gtk_clipboard_set_image(clipboard, pixbuf);
+}
