@@ -173,7 +173,7 @@ GLADE_CB void on_manual1_activate(GtkMenuItem* menuitem, gpointer user_data)
 	gchar *path = g_strconcat(inst_paths.help_dir, _("Manual_en.html"), NULL);
 
 	if(go_to_bookmark(path) < 0)
-		msg_box1("Error", "Failed to run browser.");
+		msg_box1(_("Error"), _("Failed to run browser."));
 	g_free(path);
 }
 
@@ -222,7 +222,7 @@ on_bug_report1_activate                (GtkMenuItem     *menuitem, gpointer
 {
 	GtkWidget *dialog;
 	const gchar *message =
-    "There are several ways to get in touch if you encounter a problem with TiLP or if you have questions, suggestions, bug reports, etc:\n- if you have general questions or problems, please consider the users' mailing list first (mailto:tilp-users@list.sf.net).\n- if you want to discuss about TiLP, you can use the TiLP forum (http://sourceforge.net/forum/?group_id=18378).\n- for bug reports, use the 'Bug Tracking System' (http://sourceforge.net/tracker/?group_id=18378).\n\nBefore e-mailing the TiLP team, make sure you have read the FAQ....";
+    _("There are several ways to get in touch if you encounter a problem with TiLP or if you have questions, suggestions, bug reports, etc:\n- if you have general questions or problems, please consider the users' mailing list first (mailto:tilp-users@list.sf.net).\n- if you want to discuss about TiLP, you can use the TiLP forum (http://sourceforge.net/forum/?group_id=18378).\n- for bug reports, use the 'Bug Tracking System' (http://sourceforge.net/tracker/?group_id=18378).\n\nBefore e-mailing the TiLP team, make sure you have read the FAQ....");
   
 	dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
 				  GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
@@ -359,7 +359,7 @@ GLADE_CB void on_tilp_button4_clicked(GtkButton* button, gpointer user_data)
 				return;
 			tilp_calc_send_tigroup(filename, mode | TIG_BACKUP);
 		}
-		else
+		else if(tifiles_file_is_backup(filename))
 			tilp_calc_send_backup(filename);
 	}
 
@@ -458,20 +458,15 @@ void on_tilp_send(gchar *user_data)
 	{
 		f = (FileEntry *) local.selection3->data;
 
-		// send os upgrades	
-		if (tifiles_file_is_flash(f->name) || tifiles_file_is_tib(f->name) || tifiles_file_is_tigroup(f->name)) 
+		// send os upgrades
+		if(tifiles_file_is_flash(f->name) || tifiles_file_is_tigroup(f->name)) 
 		{
-			if (!strcasecmp(tifiles_fext_get(f->name), tifiles_fext_of_flash_os(options.calc_model))) 
+			if(tifiles_file_test(f->name, TIFILE_OS, options.calc_model))
 			{
 				if (tilp_calc_send_os(f->name) != 0)
 					return;
 			} 
-			else if (tifiles_file_is_tib(f->name)) 
-			{
-				if (tilp_calc_send_os(f->name) != 0)
-					return;
-			}
-			else
+			else if(tifiles_file_is_app(f->name))
 			{
 				ret1 = tilp_calc_send_app();
 				if(!ret1)
@@ -493,7 +488,7 @@ void on_tilp_send(gchar *user_data)
 		target = g_strdup(user_data);
 
 		// change target folder
-		if(strcmp(target, ""))
+		if(strcmp(target, "") && strcmp(target, "<FLASH>"))
 			tilp_local_change_folder(target);
 
 		// and wait for action
