@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_calcs.c 3061 2006-11-10 23:57:23Z kevinkofler $ */
+/* $Id: tilp_calcs.c 4156 2008-03-26 13:18:03Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -67,7 +67,7 @@ static void tilp_options_increase_timeout(void)
 	ticables_options_set_timeout(cable_handle, 
 		options.calc_model == CALC_TI83P || options.calc_model == CALC_TI84P ? 
 		(options.cable_timeout > 300 ? options.cable_timeout : 300) :
-		(options.cable_timeout > 100 ? options.cable_timeout : 100));
+		(options.cable_timeout > 150 ? options.cable_timeout : 150));
 }
 
 /*
@@ -85,23 +85,21 @@ int tilp_calc_isready(void)
 	win32 = 0;
 #endif
 	
-	/* Hot-plug: we have to reopen cable because calc might have turned
-	   off while using TiLP.
+	/* Hot-plug: we have to reopen USB cable because calc might have 
+	   turned off while using TiLP.
 	   Note: Titanium does _not_ like too fast close/open under Linux. 
 	*/
 
 	if(!win32 && options.calc_model == CALC_TI89T_USB)
 	  {
-	    //printf("hotplug: nothing !\n");
+	    // does nothing here due to Titanium firmware bug
 	  }
 	else if((options.cable_model == CABLE_USB || 
 	   options.cable_model == CABLE_DEV))
 	  {
-	    //printf("hotplug: reopen !\n");
 		tilp_device_close();
 		tilp_device_open();
 	}
-	
 
 	// first check: fast
 	to = ticables_options_set_timeout(cable_handle, 10);
@@ -114,18 +112,26 @@ int tilp_calc_isready(void)
 		{
 		case CALC_TI89:
 		case CALC_TI89T:
-			err = ticalcs_calc_send_key(calc_handle, 277);
+			err = ticalcs_calc_send_key(calc_handle, 277);	//KEY89_HOME
 			break;
 		case CALC_TI92:
 		case CALC_TI92P:
 		case CALC_V200:
-			err = ticalcs_calc_send_key(calc_handle, 8273);
+			err = ticalcs_calc_send_key(calc_handle, 8273);	//
 			break;
 
 		default: break;
 		}
 	}
-	
+
+	if(options.calc_model == CALC_NSPIRE)
+	{
+		if(err)
+			return err;
+		else
+			return 0;
+	}
+
 	if(err) 
 	{
 		// second check: slower
@@ -238,12 +244,19 @@ int tilp_calc_idlist(int to_file)
 	}
 	
 	strcpy(buffer, _("ID-LIST : "));
-	strncat(buffer, idlist, 5);
-	strcat(buffer, "-");
-	strncat(buffer, idlist + 5, 5);
-	strcat(buffer, "-");
-	strncat(buffer, idlist + 5 + 5, 4);
-	strcat(buffer, "\0");
+	if(options.calc_model != CALC_NSPIRE)
+	{
+		strncat(buffer, idlist, 5);
+		strcat(buffer, "-");
+		strncat(buffer, idlist + 5, 5);
+		strcat(buffer, "-");
+		strncat(buffer, idlist + 5 + 5, 4);
+		strcat(buffer, "\0");
+	}
+	else
+	{
+		strcat(buffer, idlist);
+	}
 
 	if(to_file)
 	{
@@ -273,6 +286,8 @@ int tilp_calc_rom_dump(void)
 	gint ret, err;
 	gchar tmp_filename[MAXCHARS];
 
+	gif->msg_box1(_("Information"), _("ROM contents is copyrighted by Texas Instruments. You are not allowed to copy and/or distribute any ROM image! For more informations, see the License Agreement provided with any FLASH OS upgrade."));
+
 	ret = gif->msg_box4(_("Warning"), _("An assembly program is about to be sent on your calculator.\nIf you have not made a backup yet, you should do one before\nproceeding with ROM dumping...\n\nFor the way of proceeding, take a look at the TiLP manual \n(especially if you have a USB cable)."));
 	if(ret != BUTTON1)
 		return -1;
@@ -293,7 +308,6 @@ int tilp_calc_rom_dump(void)
 		case CALC_TI85: gif->msg_box1("Information", "Launch the ROM dumper on your TI-85 by CUSTOM, F1, scroll down to ROMDUMP, ENTER. Next, press Close."); break;
 		case CALC_TI86: gif->msg_box1("Information", "Launch the ROM dumper on your TI-86 by typing ASM(ROMDump), ENTER. Next, press Close."); break;
 		case CALC_TI84P_USB: gif->msg_box1("Information", "Launch the ROM dumper on your TI-8X+ by entering the following commands: PRGM, EXEC, ROMDUMP. Next, press Close."); break;
-		case CALC_TI89T_USB: gif->msg_box1("Information", "Launch the ROM dumper on your Titanium by typing romdump(), ENTER. Next, press Close."); break;
 	}
 
 	/* Get data from dumper */
@@ -330,8 +344,7 @@ int tilp_calc_send_app(void)
 	{
 		FileEntry *f = (FileEntry *)sel->data;
 
-		if(tifiles_file_is_flash(f->name) && 
-			!strcasecmp(tifiles_fext_get(f->name), tifiles_fext_of_flash_os(options.calc_model)))
+		if(tifiles_file_test(f->name, TIFILE_OS, CALC_NONE))
 		{
 			gif->msg_box1(_("Error"), _("You can not send variables/applications and upgrades simultaneously."));
 			return 0;
@@ -406,8 +419,7 @@ int tilp_calc_send_os(const char *filename)
 		return -1;
 	}
 
-	if(strcasecmp(tifiles_fext_get(filename), tifiles_fext_of_flash_os(options.calc_model)) &&
-		!tifiles_file_is_tib(filename)) 
+	if(!tifiles_file_test(filename, TIFILE_OS, options.calc_model))
 	{
 		gif->msg_box1(_("Error"),
 			     _("It's not an FLASH upgrade or this FLASH upgrade is not intended for this calculator type."));
@@ -418,6 +430,10 @@ int tilp_calc_send_os(const char *filename)
 	if(ret == BUTTON2)
 		return -1;
 
+	if(options.calc_model == CALC_NSPIRE)
+		if(tilp_calc_isready())
+			return -1;
+
 	tilp_options_increase_timeout();
 
 	gif->create_pbar_(FNCT_SEND_OS, _("Upgrading OS"));
@@ -466,7 +482,7 @@ int tilp_calc_recv_app(void)
 		gtk_update.pbar();
 		gtk_update.refresh();
 
-		str = ticonv_varname_to_filename(options.calc_model, ve->name);
+		str = ticonv_varname_to_filename(options.calc_model, ve->name, ve->type);
 		strcpy(filename, str);
 		strcat(filename, ".");
 		strcat(filename, tifiles_vartype2fext(options.calc_model, ve->type));
@@ -529,14 +545,12 @@ int tilp_calc_send_var(void)
 		{
 			continue;
 		}
-		if(tifiles_file_is_flash(f->name) && 
-			!strcasecmp(tifiles_fext_get(f->name), tifiles_fext_of_flash_os(options.calc_model)))
+		if(tifiles_file_test(f->name, TIFILE_OS, options.calc_model))
 		{
 			gif->msg_box1(_("Error"), _("You can not send both variables/applications and upgrades simultaneously."));
 			return 0;
 		}
-		else if(tifiles_file_is_flash(f->name) && 
-			!strcasecmp(tifiles_fext_get(f->name), tifiles_fext_of_flash_app(options.calc_model)))
+		else if(tifiles_file_is_app(f->name))
 		{
 			continue;
 		}
@@ -686,10 +700,10 @@ tcrv1:
 			return -1;
 		}
 
-		varname = ticonv_varname_to_filename(options.calc_model, ve->name);
-		fldname = ticonv_varname_to_filename(options.calc_model, ve->folder);
+		varname = ticonv_varname_to_filename(options.calc_model, ve->name, ve->type);
+		fldname = ticonv_varname_to_filename(options.calc_model, ve->folder, -1);
 
-		if(tifiles_has_folder(options.calc_model))
+		if(tifiles_has_folder(options.calc_model) && options.calc_model != CALC_NSPIRE)
 			dst_filename = g_strconcat(local.cwdir, G_DIR_SEPARATOR_S, 
 				fldname, ".", varname, ".",
 				tifiles_vartype2fext(options.calc_model, ve->type), NULL);
@@ -843,7 +857,7 @@ static int tilp_calc_recv_var2(void)
 	if(ve)
 	{
 		//single
-		basename = ticonv_varname_to_filename(options.calc_model, ve->name);
+		basename = ticonv_varname_to_filename(options.calc_model, ve->name, ve->type);
 		dst_filename = g_strconcat(local.cwdir, G_DIR_SEPARATOR_S, basename, 
 			".", tifiles_vartype2fext(options.calc_model, ve->type), NULL);
 		tilp_file_move_with_check(tmp_filename, dst_filename);
@@ -885,6 +899,42 @@ int tilp_calc_recv_var(void)
 	return 0;
 }
 
+int tilp_calc_check_version(const char *ti9x_ver, const char *ti8x_ver)
+{
+	if(tifiles_is_flash(options.calc_model))
+	{
+		CalcInfos infos;
+		int err;
+
+		err = ticalcs_calc_get_version(calc_handle, &infos);
+		if(tilp_err(err))
+			return -1;
+
+		if(tifiles_calc_is_ti9x(options.calc_model))
+		{
+			if(strcmp(infos.os_version, ti9x_ver) < 0)
+			{
+				gchar *str = g_strdup_printf(_("You need AMS >=%s mini for this operation."), ti9x_ver);
+				gif->msg_box1(_("Information"), str);
+				g_free(str);
+
+				return -1;
+			}
+		} 
+		else if(tifiles_calc_is_ti8x(options.calc_model))
+		{
+			if(strcmp(infos.os_version, ti8x_ver) < 0)
+			{
+				gchar *str = g_strdup_printf(_("You need OS >=%s mini for this operation."), ti8x_ver);
+				gif->msg_box1(_("Information"), str);
+				return -1;
+			}
+		}
+	}
+
+	return 0;
+}
+
 int tilp_calc_del_var(void)
 {
 	GList *sel;
@@ -899,21 +949,8 @@ int tilp_calc_del_var(void)
 	if(!(ticalcs_calc_features(calc_handle) & OPS_DELVAR))
 		return 0;
 
-	if(options.calc_model == CALC_TI89 || options.calc_model == CALC_TI92P ||
-		options.calc_model == CALC_TI89T || options.calc_model == CALC_V200)
-	{
-		CalcInfos infos;
-
-		err = ticalcs_calc_get_version(calc_handle, &infos);
-		if(tilp_err(err))
-			return -1;
-
-		if(strcmp(infos.os_version, "2.09") < 0)
-		{
-			gif->msg_box1(_("Information"), _("You need AMS 2.09 mini for this operation."));
-			return -1;
-		}
-	}
+	if(tilp_calc_check_version("2.09", "2.00") < 0)
+		return -1;
 
 	if(options.overwrite)
 	{
@@ -922,7 +959,6 @@ int tilp_calc_del_var(void)
 			return 0;
 	}
 
-	
 	gif->create_pbar_(FNCT_DEL_VAR, _("Deleting..."));
 
 	tilp_options_increase_timeout();
@@ -997,32 +1033,33 @@ int tilp_calc_new_fld(void)
 	return 0;
 }
 
-#ifdef _DEBUG
-# define EXTRA_INFOS 1
-#else
-# define EXTRA_INFOS 0
-#endif
-
 const char* format_bytes(unsigned long value)
 {
 	static char str[16];
 
 	if(value < 64*1024)
 	{
-		g_snprintf(str, sizeof(str), "%lu bytes", value);
+		g_snprintf(str, sizeof(str), _("%lu bytes"), value);
 	}
 	else if(value < 1024*1024)
 	{
-		g_snprintf(str, sizeof(str), "%lu KB", value >> 10);
+		g_snprintf(str, sizeof(str), _("%lu KB"), value >> 10);
 	}
 	else
 	{
-		g_snprintf(str, sizeof(str), "%lu MB", value >> 20);
+		g_snprintf(str, sizeof(str), _("%lu MB"), value >> 20);
 	}
 
 	return (const char *)str;
 }
 
+#define LINE_FEED	\
+	{	\
+		tmp = g_strdup_printf("%s\n", str);	\
+		g_free(str);	\
+		str = tmp;	\
+	}
+
 int tilp_calc_get_infos(CalcInfos *infos)
 {
 	int err;
@@ -1039,25 +1076,76 @@ int tilp_calc_get_infos(CalcInfos *infos)
 	if(tilp_err(err))
 		return -1;
 
-#if EXTRA_INFOS
-	if(infos->mask & INFOS_PRODUCT_NUMBER)
+	if(infos->mask & INFOS_PRODUCT_NAME)
 	{
-		tmp = g_strdup_printf("%sProduct Number: %08x\n", str, infos->product_number);
+		tmp = g_strdup_printf(_("%sProduct Name: %s\n"), str, infos->product_name);
 		g_free(str);
 		str = tmp;
 	}
+
+	if(infos->mask & INFOS_PRODUCT_ID)
+	{
+		tmp = g_strdup_printf(_("%sProduct Id: %s\n"), str, infos->product_id);
+		g_free(str);
+		str = tmp;
+	} else if(infos->mask & INFOS_MAIN_CALC_ID) // for compat
+	{
+		tmp = g_strdup_printf(_("%sProduct Id: %s\n"), str, infos->main_calc_id);
+		g_free(str);
+		str = tmp;
+	}
+
 	if(infos->mask & INFOS_LANG_ID)
 	{
 		tmp = g_strdup_printf("%sLanguage Id: %i %i\n", str, infos->language_id, infos->sub_lang_id);
 		g_free(str);
 		str = tmp;
 	}
+
+	LINE_FEED;
+
 	if(infos->mask & INFOS_DEVICE_TYPE)
 	{
 		tmp = g_strdup_printf("%sDevice Type: %02x\n", str, infos->device_type);
 		g_free(str);
 		str = tmp;
 	}
+
+	if(infos->mask & INFOS_HW_VERSION)
+	{
+		tmp = g_strdup_printf(_("%sHardware Version: %i\n"), str, infos->hw_version);
+		g_free(str);
+		str = tmp;
+	}
+
+	if(infos->mask & INFOS_BOOT_VERSION)
+	{
+		tmp = g_strdup_printf(_("%sBoot Version: %s\n"), str, infos->boot_version);
+		g_free(str);
+		str = tmp;
+	}
+	if(infos->mask & INFOS_OS_VERSION)
+	{
+		tmp = g_strdup_printf(_("%sOS Version: %s\n"), str, infos->os_version);
+		g_free(str);
+		str = tmp;
+	}
+	
+	if(infos->mask & INFOS_RUN_LEVEL)
+	{
+		tmp = g_strdup_printf("%sRun level: %s\n", str, (infos->run_level == 2) ? "OS" : "boot");
+		g_free(str);
+		str = tmp;
+	}
+	if(infos->mask & INFOS_CLOCK_SPEED)
+	{
+		tmp = g_strdup_printf("%sClock speed: %i MHz\n", str, infos->clock_speed);
+		g_free(str);
+		str = tmp;
+	}
+
+	LINE_FEED;
+
 	if(infos->mask & INFOS_LCD_WIDTH)
 	{
 		tmp = g_strdup_printf("%sLCD width: %i pixels\n", str, infos->lcd_width);
@@ -1070,88 +1158,63 @@ int tilp_calc_get_infos(CalcInfos *infos)
 		g_free(str);
 		str = tmp;
 	}
+	if(infos->mask & INFOS_BPP)
+	{
+		tmp = g_strdup_printf("%sBits per pixel: %i\n", str, infos->bits_per_pixel);
+		g_free(str);
+		str = tmp;
+	}
+	
+	LINE_FEED;
 	
-	{
-		tmp = g_strdup_printf("%s\n\n", str);
-		g_free(str);
-		str = tmp;
-	}
-#endif
-	if(infos->mask & INFOS_PRODUCT_NAME)
-	{
-		tmp = g_strdup_printf("%sProduct Name: <%s>\n", str, infos->product_name);
-		g_free(str);
-		str = tmp;
-	}
-	if(infos->mask & INFOS_MAIN_CALC_ID)
-	{
-		tmp = g_strdup_printf("%sCalculator Id: %s\n", str, infos->main_calc_id);
-		g_free(str);
-		str = tmp;
-	}
-	if(infos->mask & INFOS_HW_VERSION)
-	{
-		tmp = g_strdup_printf("%sHardware Version: %i\n", str, infos->hw_version);
-		g_free(str);
-		str = tmp;
-	}
-	if(infos->mask & INFOS_BOOT_VERSION)
-	{
-		tmp = g_strdup_printf("%sBoot Version: %s\n", str, infos->boot_version);
-		g_free(str);
-		str = tmp;
-	}
-	if(infos->mask & INFOS_OS_VERSION)
-	{
-		tmp = g_strdup_printf("%sOS Version: %s\n", str, infos->os_version);
-		g_free(str);
-		str = tmp;
-	}
 	if(infos->mask & INFOS_RAM_PHYS)
 	{
-		tmp = g_strdup_printf("%sPhysical RAM: %s\n", str, 
+		tmp = g_strdup_printf(_("%sPhysical RAM: %s\n"), str, 
 				      format_bytes((unsigned int)infos->ram_phys));
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_RAM_USER)
 	{
-		tmp = g_strdup_printf("%sUser RAM: %s\n", str, 
+		tmp = g_strdup_printf(_("%sUser RAM: %s\n"), str, 
 				      format_bytes((unsigned int)infos->ram_user));
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_RAM_FREE)
 	{
-		tmp = g_strdup_printf("%sFree RAM: %s\n", str, 
+		tmp = g_strdup_printf(_("%sFree RAM: %s\n"), str, 
 				      format_bytes((unsigned int)infos->ram_free));
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_FLASH_PHYS)
 	{
-		tmp = g_strdup_printf("%sPhysical FLASH: %s\n", str, 
+		tmp = g_strdup_printf(_("%sPhysical FLASH: %s\n"), str, 
 				      format_bytes((unsigned int)infos->flash_phys));
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_FLASH_USER)
 	{
-		tmp = g_strdup_printf("%sUser FLASH: %s\n", str, 
+		tmp = g_strdup_printf(_("%sUser FLASH: %s\n"), str, 
 				      format_bytes((unsigned int)infos->flash_user));
 		g_free(str);
 		str = tmp;
 	}
 	if(infos->mask & INFOS_FLASH_FREE)
 	{
-		tmp = g_strdup_printf("%sFree FLASH: %s\n", str, 
+		tmp = g_strdup_printf(_("%sFree FLASH: %s\n"), str, 
 				      format_bytes((unsigned int)infos->flash_free));
 		g_free(str);
 		str = tmp;
 	}
+
+	LINE_FEED;
+
 	if(infos->mask & INFOS_BATTERY)
 	{
-		tmp = g_strdup_printf("%sBattery: %s\n", str, infos->battery ? "good" : "low");
+		tmp = g_strdup_printf(_("%sBattery: %s\n"), str, infos->battery ? _("good") : _("low"));
 		g_free(str);
 		str = tmp;
 	}
