@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_paths.c 3062 2006-11-11 00:02:04Z kevinkofler $ */
+/* $Id: tilp_paths.c 3218 2007-02-24 17:57:22Z roms $ */
 
 /*  TiLP - Tilp Is a Linking Program
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -111,8 +111,12 @@ static void init_win32_paths(void)
 	    g_strconcat(inst_paths.base_dir, "", NULL);
 	inst_paths.glade_dir =
 	    g_strconcat(inst_paths.base_dir, "glade\\", NULL);
+	#ifdef __MINGW32__
+	inst_paths.home_dir = g_get_current_dir();
+	#else
 	inst_paths.home_dir = 
 	    g_strconcat(inst_paths.base_dir, "My TI files\\", NULL);
+	#endif
 
 #ifdef ENABLE_NLS
 	inst_paths.locale_dir =
